# Infini Generator 2

<!-- start index -->
Infini 文本输入输出流 2

## 版本

此文档为 Infini 2 文档，如果你正在搜寻 Infini 1.x 的文档，请前往[旧的 Infini 文档](./docs/v1.0/README.md)。

## 版权

水系 × [浊莲](https://github.com/noctisynth)依照 MIT 协议开源 Infini。
<!-- end index -->